@@ -43,7 +43,7 @@ class TestDatabase(unittest.TestCase):
 
     def test_node_allocation(self):
         user = self.database.get_user('test1@example.com')
-        self.assertEquals(user, None)
+        self.assertEqual(user, None)
 
         user = self.database.allocate_user('test1@example.com')
         wanted = 'https://phx12'
@@ -467,23 +467,23 @@ class TestDatabase(unittest.TestCase):
     def test_build_old_range(self):
         params = dict()
         sql = self.database._build_old_user_query(None, params)
-        self.assert_(sql.text.find("uid > :start") < 0)
-        self.assert_(sql.text.find("uid < :end") < 0)
+        self.assertTrue(sql.text.find("uid > :start") < 0)
+        self.assertTrue(sql.text.find("uid < :end") < 0)
         self.assertIsNone(params.get("start"))
         self.assertIsNone(params.get("end"))
 
         params = dict()
         rrange = (None, "abcd")
         sql = self.database._build_old_user_query(rrange, params)
-        self.assert_(sql.text.find("uid > :start") < 0)
-        self.assert_(sql.text.find("uid < :end") > 0)
+        self.assertTrue(sql.text.find("uid > :start") < 0)
+        self.assertTrue(sql.text.find("uid < :end") > 0)
         self.assertIsNone(params.get("start"))
         self.assertEqual(params.get("end"), rrange[1])
 
         params = dict()
         rrange = ("1234", "abcd")
         sql = self.database._build_old_user_query(rrange, params)
-        self.assert_(sql.text.find("uid > :start") > 0)
-        self.assert_(sql.text.find("uid < :end") > 0)
+        self.assertTrue(sql.text.find("uid > :start") > 0)
+        self.assertTrue(sql.text.find("uid < :end") > 0)
         self.assertEqual(params.get("start"), rrange[0])
         self.assertEqual(params.get("end"), rrange[1])
